@@ -515,6 +515,10 @@ class DataLoader:
         """Write flags to the database."""
         DataLoader.check_check_passed(check_passed=check_passed)
 
+        if flags.is_empty():
+            logger.info("No flags to write")
+            return True
+
         db = SQLAlchemyDatabase.from_kedro()
 
         all_flags = [f.value for f in FlagLevels]
@@ -591,9 +595,9 @@ class DataLoader:
             )
             .drop(["description", "name", "var_type", "companyID"])
             .explode("levels")
-            .with_row_count("order")
+            .with_row_index("order")
             .rename({"levels": "level"})
-            .select(["featureID", "level", pl.col("order").cast(pl.Int8)])
+            .select(["featureID", "level", pl.col("order").cast(pl.Int32)])
         )
 
         db.handle_insertion_multi_line(
@@ -658,7 +662,7 @@ class DataLoader:
             data=feature_map,
             mode=self.insertion_mode,
             returning_id=False,
-            parallel_workers=1,  # anything not time-sku should use 1 worker
+            parallel_workers=2,  # anything not time-sku should use 2 worker
         )
 
         logger.info("Writing %s features to the database complete, wrote %d rows", feature_type, len(feature_map))
@@ -838,6 +842,10 @@ class DataLoader:
         """Write time-region data into the database."""
         DataLoader.check_check_passed(check_passed=check_passed)
 
+        if time_region_feature_description_map.is_empty():
+            logger.info("No time-region feature data to write")
+            return True
+
         db = SQLAlchemyDatabase.from_kedro()
 
         # Get all dates from the database
