@@ -904,10 +904,15 @@ class DataValidator:
     def _validate_text_feature_values(self, description: pl.DataFrame, data: pl.DataFrame) -> None:
         """Validate that text feature values are strings or null."""
 
-        # check that columns "value" in data is Utf8
-        if data.select(pl.col("value").dtype != pl.Utf8):
+        if description.select(pl.col("var_type") == VariableTypes.TEXT.value).is_empty():
+            print("No text features to validate.")
+            return  # No text features to validate
+        print(description)
+
+        # If text features present, the entire value columns must be String
+        if data.select(pl.col("value")).dtypes[0] != pl.Utf8:
             raise TypeError("Text feature values must be of type Utf8")
-    
+            
 
 
     def _validate_binary_feature_values(self, description: pl.DataFrame, data: pl.DataFrame) -> None:
